@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,32 +12,30 @@
 
 #pragma once
 
+#include <seqan3/std/iterator>
 #include <memory>
 #include <optional>
+#include <seqan3/std/ranges>
 #include <type_traits>
 
 #include <seqan3/alignment/configuration/align_config_band.hpp>
 #include <seqan3/alignment/configuration/align_config_scoring_scheme.hpp>
 #include <seqan3/alignment/exception.hpp>
+#include <seqan3/alignment/matrix/detail/aligned_sequence_builder.hpp>
 #include <seqan3/alignment/matrix/trace_directions.hpp>
 #include <seqan3/alignment/pairwise/align_result_selector.hpp>
 #include <seqan3/alignment/pairwise/detail/concept.hpp>
 #include <seqan3/alignment/pairwise/detail/type_traits.hpp>
-#include <seqan3/alignment/matrix/detail/aligned_sequence_builder.hpp>
-
+#include <seqan3/core/detail/deferred_crtp_base.hpp>
 #include <seqan3/core/detail/empty_type.hpp>
-#include <seqan3/core/simd/concept.hpp>
-#include <seqan3/core/simd/simd.hpp>
-#include <seqan3/core/simd/simd_traits.hpp>
-#include <seqan3/core/simd/view_to_simd.hpp>
-#include <seqan3/core/type_traits/deferred_crtp_base.hpp>
-#include <seqan3/core/type_traits/function.hpp>
-#include <seqan3/range/container/aligned_allocator.hpp>
-#include <seqan3/range/views/drop.hpp>
-#include <seqan3/range/views/get.hpp>
-#include <seqan3/range/views/take.hpp>
-#include <seqan3/std/iterator>
-#include <seqan3/std/ranges>
+#include <seqan3/io/detail/take_view.hpp>
+#include <seqan3/utility/container/aligned_allocator.hpp>
+#include <seqan3/utility/simd/concept.hpp>
+#include <seqan3/utility/simd/simd.hpp>
+#include <seqan3/utility/simd/simd_traits.hpp>
+#include <seqan3/utility/simd/views/to_simd.hpp>
+#include <seqan3/utility/type_traits/function_traits.hpp>
+#include <seqan3/utility/views/elements.hpp>
 
 namespace seqan3::detail
 {
@@ -205,8 +203,8 @@ public:
         static_assert(simd_concept<typename traits_t::trace_type>, "Expected simd trace type.");
 
         // Extract the batch of sequences for the first and the second sequence.
-        auto sequence1_range = indexed_sequence_pairs | views::get<0> | views::get<0>;
-        auto sequence2_range = indexed_sequence_pairs | views::get<0> | views::get<1>;
+        auto sequence1_range = indexed_sequence_pairs | views::elements<0> | views::elements<0>;
+        auto sequence2_range = indexed_sequence_pairs | views::elements<0> | views::elements<1>;
 
         // Initialise the find_optimum policy in the simd case.
         this->initialise_find_optimum_policy(sequence1_range,
@@ -250,7 +248,7 @@ private:
 
         std::vector<simd_score_t, aligned_allocator<simd_score_t, alignof(simd_score_t)>> simd_sequence{};
 
-        for (auto && simd_vector_chunk : sequences | views::to_simd<simd_score_t>(traits_t::padding_symbol))
+        for (auto && simd_vector_chunk : sequences | views::to_simd<simd_score_t>(this->scoring_scheme.padding_symbol))
             for (auto && simd_vector : simd_vector_chunk)
                 simd_sequence.push_back(std::move(simd_vector));
 
@@ -398,9 +396,9 @@ private:
         // Recursion phase: compute column-wise the alignment matrix.
         // ----------------------------------------------------------------------------
 
-        for (auto const & seq1_value : sequence1)
+        for (auto const & alphabet1 : sequence1)
         {
-            compute_alignment_column<true>(seq1_value, sequence2);
+            compute_alignment_column<true>(this->scoring_scheme_profile_column(alphabet1), sequence2);
             finalise_last_cell_in_column(true);
         }
 
@@ -424,17 +422,18 @@ private:
 
         // Allocate and initialise first column.
         this->allocate_matrix(sequence1, sequence2, band, this->alignment_state);
-        size_t last_row_index = this->score_matrix.band_row_index;
-        initialise_first_alignment_column(sequence2 | views::take(last_row_index));
+        using row_index_t = std::ranges::range_difference_t<sequence2_t>;
+        row_index_t last_row_index = this->score_matrix.band_row_index;
+        initialise_first_alignment_column(std::views::take(sequence2, last_row_index));
 
         // ----------------------------------------------------------------------------
         // 1st recursion phase: iterate as long as the band intersects with the first row.
         // ----------------------------------------------------------------------------
 
-        size_t sequence2_size = std::ranges::distance(sequence2);
-        for (auto const & seq1_value : sequence1 | views::take(this->score_matrix.band_col_index))
+        row_index_t sequence2_size = std::ranges::distance(sequence2);
+        for (auto const & seq1_value : std::views::take(sequence1, this->score_matrix.band_col_index))
         {
-            compute_alignment_column<true>(seq1_value, sequence2 | views::take(++last_row_index));
+            compute_alignment_column<true>(seq1_value, std::views::take(sequence2, ++last_row_index));
             // Only if band reached last row of matrix the last cell might be tracked.
             finalise_last_cell_in_column(last_row_index >= sequence2_size);
         }
@@ -444,7 +443,7 @@ private:
         // ----------------------------------------------------------------------------
 
         size_t first_row_index = 0;
-        for (auto const & seq1_value : sequence1 | views::drop(this->score_matrix.band_col_index))
+        for (auto const & seq1_value : std::views::drop(sequence1, this->score_matrix.band_col_index))
         {
             // In the second phase the band moves in every column one base down on the second sequence.
             compute_alignment_column<false>(seq1_value, sequence2 | views::slice(first_row_index++, ++last_row_index));
@@ -624,8 +623,9 @@ private:
 
         if constexpr (traits_t::compute_end_positions)
         {
-            res.end_positions = alignment_coordinate{column_index_type{this->alignment_state.optimum.column_index},
-                                                     row_index_type{this->alignment_state.optimum.row_index}};
+            using alignment_coordinate_t = detail::advanceable_alignment_coordinate<>;
+            res.end_positions = alignment_coordinate_t{column_index_type{this->alignment_state.optimum.column_index},
+                                                       row_index_type{this->alignment_state.optimum.row_index}};
             // At some point this needs to be refactored so that it is not necessary to adapt the coordinate.
             if constexpr (traits_t::is_banded)
                 res.end_positions.second += res.end_positions.first - this->trace_matrix.band_col_index;
@@ -635,8 +635,12 @@ private:
         {
             // Get a aligned sequence builder for banded or un-banded case.
             aligned_sequence_builder builder{sequence1, sequence2};
-            auto optimum_coordinate = alignment_coordinate{column_index_type{this->alignment_state.optimum.column_index},
-                                                           row_index_type{this->alignment_state.optimum.row_index}};
+
+            detail::matrix_coordinate const optimum_coordinate
+            {
+                detail::row_index_type{this->alignment_state.optimum.row_index},
+                detail::column_index_type{this->alignment_state.optimum.column_index}
+            };
             auto trace_res = builder(this->trace_matrix.trace_path(optimum_coordinate));
             res.begin_positions.first = trace_res.first_sequence_slice_positions.first;
             res.begin_positions.second = trace_res.second_sequence_slice_positions.first;
