@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -17,10 +17,10 @@
 
 #include <seqan3/alignment/pairwise/detail/type_traits.hpp>
 #include <seqan3/core/detail/empty_type.hpp>
-#include <seqan3/core/detail/type_inspection.hpp>
-#include <seqan3/core/simd/view_to_simd.hpp>
-#include <seqan3/range/container/aligned_allocator.hpp>
-#include <seqan3/range/views/get.hpp>
+#include <seqan3/utility/container/aligned_allocator.hpp>
+#include <seqan3/utility/detail/type_name_as_string.hpp>
+#include <seqan3/utility/simd/views/to_simd.hpp>
+#include <seqan3/utility/views/elements.hpp>
 
 namespace seqan3::detail
 {
@@ -57,7 +57,6 @@ protected:
 
     static_assert(!std::same_as<alignment_result_type, empty_type>, "Alignment result type was not configured.");
 
-
 public:
     /*!\name Constructors, destructor and assignment
      * \{
@@ -145,6 +144,7 @@ public:
                                          std::move(idx),
                                          this->optimal_score,
                                          this->optimal_coordinate,
+                                         alignment_matrix,
                                          callback);
         }
     }
@@ -161,8 +161,8 @@ public:
         using original_score_t = typename traits_type::original_score_type;
 
         // Extract the batch of sequences for the first and the second sequence.
-        auto seq1_collection = indexed_sequence_pairs | views::get<0> | views::get<0>;
-        auto seq2_collection = indexed_sequence_pairs | views::get<0> | views::get<1>;
+        auto seq1_collection = indexed_sequence_pairs | views::elements<0> | views::elements<0>;
+        auto seq2_collection = indexed_sequence_pairs | views::elements<0> | views::elements<1>;
 
         this->initialise_tracker(seq1_collection, seq2_collection);
 
@@ -170,8 +170,12 @@ public:
         thread_local simd_collection_t simd_seq1_collection{};
         thread_local simd_collection_t simd_seq2_collection{};
 
-        convert_batch_of_sequences_to_simd_vector(simd_seq1_collection, seq1_collection, traits_type::padding_symbol);
-        convert_batch_of_sequences_to_simd_vector(simd_seq2_collection, seq2_collection, traits_type::padding_symbol);
+        convert_batch_of_sequences_to_simd_vector(simd_seq1_collection,
+                                                  seq1_collection,
+                                                  this->scoring_scheme.padding_symbol);
+        convert_batch_of_sequences_to_simd_vector(simd_seq2_collection,
+                                                  seq2_collection,
+                                                  this->scoring_scheme.padding_symbol);
 
         size_t const sequence1_size = std::ranges::distance(simd_seq1_collection);
         size_t const sequence2_size = std::ranges::distance(simd_seq2_collection);
@@ -191,6 +195,7 @@ public:
                                          std::move(idx),
                                          std::move(score),
                                          std::move(coordinate),
+                                         alignment_matrix,
                                          callback);
             ++index;
         }
@@ -274,8 +279,11 @@ protected:
         // Iteration phase: compute column-wise the alignment matrix.
         // ---------------------------------------------------------------------
 
-        for (auto sequence1_value : sequence1)
-            compute_column(*++alignment_matrix_it, *++indexed_matrix_it, sequence1_value, sequence2);
+        for (auto alphabet1 : sequence1)
+            compute_column(*++alignment_matrix_it,
+                           *++indexed_matrix_it,
+                           this->scoring_scheme_profile_column(alphabet1),
+                           sequence2);
 
         // ---------------------------------------------------------------------
         // Final phase: track score of last column
@@ -349,13 +357,13 @@ protected:
     /*!\brief Initialise any column of the alignment matrix except the first one.
      * \tparam alignment_column_t The type of the alignment column; must model std::ranges::input_range.
      * \tparam cell_index_column_t The type of the indexed column; must model std::ranges::input_range.
-     * \tparam sequence1_value_t The value type of sequence1; must model seqan3::semialphabet.
+     * \tparam alphabet1_t The type of the current symbol of sequence1.
      * \tparam sequence2_t The type of the second sequence; must model std::ranges::input_range.
      *
      * \param[in] alignment_column The current alignment matrix column to compute.
      * \param[in] cell_index_column The current index matrix column to get the respective cell indices.
-     * \param[in] sequence1_value The current symbol of sequence1.
-     * \param[in] sequence2 The second sequence to align against `sequence1_value`.
+     * \param[in] alphabet1 The current symbol of sequence1.
+     * \param[in] sequence2 The second sequence to align against `alphabet1`.
      *
      * \details
      *
@@ -366,14 +374,14 @@ protected:
      */
     template <std::ranges::input_range alignment_column_t,
               std::ranges::input_range cell_index_column_t,
-              typename sequence1_value_t,
+              typename alphabet1_t,
               std::ranges::input_range sequence2_t>
     //!\cond
-        requires semialphabet<sequence1_value_t> || simd_concept<sequence1_value_t>
+        requires semialphabet<alphabet1_t> || simd_concept<alphabet1_t>
     //!\endcond
     void compute_column(alignment_column_t && alignment_column,
                         cell_index_column_t && cell_index_column,
-                        sequence1_value_t const & sequence1_value,
+                        alphabet1_t const & alphabet1,
                         sequence2_t && sequence2)
     {
         using score_type = typename traits_type::score_type;
@@ -393,12 +401,12 @@ protected:
         // Iteration phase: iterate over column and compute each cell
         // ---------------------------------------------------------------------
 
-        for (auto const & sequence2_value : sequence2)
+        for (auto const & alphabet2 : sequence2)
         {
             auto cell = *++alignment_column_it;
             score_type next_diagonal = cell.best_score();
             *alignment_column_it = this->track_cell(
-                this->compute_inner_cell(diagonal, cell, this->scoring_scheme.score(sequence1_value, sequence2_value)),
+                this->compute_inner_cell(diagonal, cell, this->scoring_scheme.score(alphabet1, alphabet2)),
                 *++cell_index_column_it);
             diagonal = next_diagonal;
         }
