@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -18,13 +18,13 @@
 #include <seqan3/std/ranges>
 #include <utility>
 
-#include <seqan3/alignment/matrix/alignment_coordinate.hpp>
-#include <seqan3/alignment/matrix/alignment_trace_algorithms.hpp>
+#include <seqan3/alignment/matrix/detail/advanceable_alignment_coordinate.hpp>
 #include <seqan3/alignment/matrix/edit_distance_score_matrix_full.hpp>
 #include <seqan3/alignment/matrix/edit_distance_trace_matrix_full.hpp>
+#include <seqan3/alignment/matrix/matrix_concept.hpp>
 #include <seqan3/alignment/pairwise/alignment_result.hpp>
 #include <seqan3/alignment/pairwise/edit_distance_fwd.hpp>
-#include <seqan3/core/algorithm/configuration.hpp>
+#include <seqan3/core/configuration/configuration.hpp>
 
 namespace seqan3::detail
 {
@@ -56,6 +56,7 @@ protected:
     edit_distance_unbanded_max_errors_policy & operator=(edit_distance_unbanded_max_errors_policy &&) noexcept
         = default; //!< Defaulted.
     ~edit_distance_unbanded_max_errors_policy() noexcept = default; //!< Defaulted.
+
     //!\}
 
     using typename edit_traits::word_type;
@@ -225,6 +226,7 @@ protected:
     edit_distance_unbanded_global_policy & operator=(edit_distance_unbanded_global_policy &&) noexcept
         = default; //!< Defaulted.
     ~edit_distance_unbanded_global_policy() noexcept = default; //!< Defaulted.
+
     //!\}
 
     //!\copydoc default_edit_distance_trait_type::score_type
@@ -269,7 +271,7 @@ protected:
     }
 
     //!\brief Returns an invalid_coordinate for this alignment.
-    alignment_coordinate invalid_coordinate() const noexcept
+    seqan3::detail::advanceable_alignment_coordinate<> invalid_coordinate() const noexcept
     {
         derived_t const * self = static_cast<derived_t const *>(this);
         return {column_index_type{std::ranges::size(self->database)}, row_index_type{std::ranges::size(self->query)}};
@@ -310,7 +312,7 @@ public:
 
     //!\brief Return the end position of the alignment
     //!       Only available if default_edit_distance_trait_type::compute_end_positions is true.
-    alignment_coordinate end_positions() const noexcept
+    seqan3::detail::advanceable_alignment_coordinate<> end_positions() const noexcept
     {
         derived_t const * self = static_cast<derived_t const *>(this);
         static_assert(edit_traits::compute_end_positions, "end_positions() can only be computed if you specify the "
@@ -349,6 +351,7 @@ protected:
     edit_distance_unbanded_semi_global_policy & operator=(edit_distance_unbanded_semi_global_policy &&) noexcept
         = default; //!< Defaulted.
     ~edit_distance_unbanded_semi_global_policy() noexcept = default; //!< Defaulted.
+
     //!\}
 
     //!\brief The base policy of this policy.
@@ -438,6 +441,7 @@ protected:
     edit_distance_unbanded_score_matrix_policy & operator=(edit_distance_unbanded_score_matrix_policy &&) noexcept
         = default; //!< Defaulted.
     ~edit_distance_unbanded_score_matrix_policy() noexcept = default; //!< Defaulted.
+
     //!\}
 
     using typename edit_traits::score_matrix_type;
@@ -517,6 +521,7 @@ protected:
     edit_distance_unbanded_trace_matrix_policy & operator=(edit_distance_unbanded_trace_matrix_policy &&) noexcept
         = default; //!< Defaulted.
     ~edit_distance_unbanded_trace_matrix_policy() noexcept = default; //!< Defaulted.
+
     //!\}
 
     using typename edit_traits::word_type;
@@ -575,7 +580,7 @@ public:
 
     //!\brief Return the begin position of the alignment.
     //!       Only available if default_edit_distance_trait_type::compute_begin_positions is true.
-    alignment_coordinate begin_positions() const noexcept
+    seqan3::detail::advanceable_alignment_coordinate<> begin_positions() const noexcept
     {
         derived_t const * self = static_cast<derived_t const *>(this);
         static_assert(edit_traits::compute_begin_positions, "begin_positions() can only be computed if you specify the "
@@ -583,8 +588,13 @@ public:
         if (!self->is_valid())
             return self->invalid_coordinate();
 
-        alignment_coordinate const back = self->end_positions();
-        return alignment_begin_positions(trace_matrix(), back);
+        auto [first, second] = self->end_positions();
+        detail::matrix_coordinate const end_positions{detail::row_index_type{second}, detail::column_index_type{first}};
+        auto trace_path = self->trace_matrix().trace_path(end_positions);
+        auto trace_path_it = std::ranges::begin(trace_path);
+        std::ranges::advance(trace_path_it, std::ranges::end(trace_path));
+        detail::matrix_coordinate const begin_positions = trace_path_it.coordinate();
+        return {detail::column_index_type{begin_positions.col}, detail::row_index_type{begin_positions.row}};
     }
 
     //!\brief Return the alignment, i.e. the actual base pair matching.
@@ -600,11 +610,11 @@ public:
         if (!self->is_valid())
             return alignment_t{};
 
-        return alignment_trace<alignment_t>(self->database,
-                                            self->query,
-                                            trace_matrix(),
-                                            self->end_positions(),
-                                            begin_positions());
+        auto [first, second] = self->end_positions();
+        detail::matrix_coordinate const end_positions{detail::row_index_type{second}, detail::column_index_type{first}};
+        aligned_sequence_builder builder{self->database, self->query};
+        auto trace_path = self->trace_matrix().trace_path(end_positions);
+        return builder(trace_path).alignment;
     }
     //!\}
 };
@@ -799,10 +809,10 @@ private:
     };
 
     //!\brief The internal state needed to compute the alignment.
-    struct compute_state : enable_state_t<compute_trace_matrix, compute_state_trace_matrix>
+    struct compute_state : enable_state_t<edit_traits::compute_trace_matrix, compute_state_trace_matrix>
     {
         //!\brief The type of hp.
-        using hp_type = std::conditional_t<compute_trace_matrix, proxy_reference<word_type>, word_type>;
+        using hp_type = std::conditional_t<edit_traits::compute_trace_matrix, proxy_reference<word_type>, word_type>;
 
         //!\brief The machine word which stores wether the current character matches.
         word_type b{};
@@ -1055,11 +1065,10 @@ public:
         if constexpr (compute_end_positions)
             cached_end_positions = this->end_positions();
 
-        if constexpr (compute_begin_positions)
+        if constexpr (compute_begin_positions && !compute_sequence_alignment)
         {
             static_assert(compute_end_positions, "End positions required to compute the begin positions.");
-            if (this->is_valid())
-                cached_begin_positions = alignment_begin_positions(this->trace_matrix(), cached_end_positions);
+            cached_begin_positions = this->begin_positions();
         }
 
         // Fill the result value type. Note we need to ask what was enabled on the user side in order to store
@@ -1080,12 +1089,15 @@ public:
         {
             if (this->is_valid())
             {
-                using alignment_t = decltype(res_vt.alignment);
-                res_vt.alignment = alignment_trace<alignment_t>(database,
-                                                                query,
-                                                                this->trace_matrix(),
-                                                                cached_end_positions,
-                                                                cached_begin_positions);
+                auto [first, second] = cached_end_positions;
+                detail::matrix_coordinate const end_positions{detail::row_index_type{second},
+                                                              detail::column_index_type{first}};
+
+                aligned_sequence_builder builder{this->database, this->query};
+                auto trace_res = builder(this->trace_matrix().trace_path(end_positions));
+                res_vt.alignment = std::move(trace_res.alignment);
+                cached_begin_positions.first = trace_res.first_sequence_slice_positions.first;
+                cached_begin_positions.second = trace_res.second_sequence_slice_positions.first;
             }
         }
 
