@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,6 +13,7 @@
 
 #pragma once
 
+#include <seqan3/std/filesystem>
 #include <iostream>
 #include <limits>
 #include <sstream>
@@ -21,9 +22,10 @@
 #include <seqan3/argument_parser/auxiliary.hpp>
 #include <seqan3/argument_parser/exceptions.hpp>
 #include <seqan3/argument_parser/validators.hpp>
-#include <seqan3/core/detail/type_inspection.hpp>
-#include <seqan3/core/type_list/traits.hpp>
-#include <seqan3/std/filesystem>
+#include <seqan3/utility/container/concept.hpp>
+#include <seqan3/utility/detail/type_name_as_string.hpp>
+#include <seqan3/utility/type_list/traits.hpp>
+#include <seqan3/version.hpp>
 
 namespace seqan3::detail
 {
@@ -114,7 +116,7 @@ protected:
     //!\endcond
     static std::string option_type_and_list_info(container_type const & container)
     {
-        return ("(\\fIList\\fP of \\fI" + get_type_name_as_string(container) + "\\fP's)");
+        return ("(\\fIList\\fP of \\fI" + get_type_name_as_string(container) + "\\fP)");
     }
 
     /*!\brief Formats the option/flag identifier pair for the help page printing.
@@ -235,7 +237,7 @@ public:
     {
         std::string id = prep_id_for_help(short_id, long_id) + " " + option_type_and_list_info(value);
         std::string info{desc};
-        info += ((spec & option_spec::REQUIRED) ? std::string{" "} : detail::to_string(" Default: ", value, ". "));
+        info += ((spec & option_spec::required) ? std::string{" "} : detail::to_string(" Default: ", value, ". "));
         info += option_validator.get_help_page_message();
         store_help_page_element([this, id, info] () { derived_t().print_list_item(id, info); }, spec);
     }
@@ -335,6 +337,10 @@ public:
                 print_line(example);
         }
 
+        print_version();
+
+        print_legal();
+
         derived_t().print_footer();
 
         std::exit(EXIT_SUCCESS); // program should not continue from here
@@ -419,6 +425,70 @@ protected:
         derived_t().print_line(text, true);
     }
 
+    //!\brief Prints the version information.
+    void print_version()
+    {
+        std::string const version_str{seqan3_version_cstring};
+
+        // Print version, date and url.
+        derived_t().print_section("Version");
+        derived_t().print_line(derived_t().in_bold("Last update: ") + meta.date, false);
+        derived_t().print_line(derived_t().in_bold(meta.app_name + " version: ") + meta.version, false);
+        derived_t().print_line(derived_t().in_bold("SeqAn version: ") + version_str, false);
+
+        if (!empty(meta.url))
+        {
+            derived_t().print_section("Url");
+            derived_t().print_line(meta.url, false);
+        }
+    }
+
+    //!\brief Prints the legal information.
+    void print_legal()
+    {
+        // Print legal stuff
+        if ((!empty(meta.short_copyright)) ||
+            (!empty(meta.long_copyright)) ||
+            (!empty(meta.citation)) ||
+            (!empty(meta.author)) ||
+            (!empty(meta.email)))
+        {
+            derived_t().print_section("Legal");
+
+            if (!empty(meta.short_copyright))
+            {
+                derived_t().print_line(derived_t().in_bold(meta.app_name + " Copyright: ") + meta.short_copyright,
+                                       false);
+            }
+
+            if (!empty(meta.author))
+            {
+                derived_t().print_line(derived_t().in_bold("Author: ") + meta.author, false);
+            }
+
+            if (!empty(meta.email))
+            {
+                derived_t().print_line(derived_t().in_bold("Contact: ") + meta.email, false);
+            }
+
+            derived_t().print_line(derived_t().in_bold("SeqAn Copyright: ") +
+                                   "2006-2021 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.", false);
+
+            if (!empty(meta.citation))
+            {
+                derived_t().print_line(derived_t().in_bold("In your academic works please cite: ") + meta.citation,
+                                       false);
+            }
+
+            if (!empty(meta.long_copyright))
+            {
+                derived_t().print_line("For full copyright and/or warranty information see " +
+                                       derived_t().in_bold("--copyright") + ".",
+                                       false);
+            }
+        }
+    }
+
     //!\brief Vector of functions that stores all calls except add_positional_option.
     std::vector<std::function<void()>> parser_set_up_calls;
     //!\brief Vector of functions that stores add_positional_option calls.
@@ -437,13 +507,13 @@ private:
      *
      * \details
      *
-     * If `spec` equals `seqan3::option_spec::HIDDEN`, the information is never added to the help page.
-     * If `spec` equals `seqan3::option_spec::ADVANCED`, the information is only added to the help page if
+     * If `spec` equals `seqan3::option_spec::hidden`, the information is never added to the help page.
+     * If `spec` equals `seqan3::option_spec::advanced`, the information is only added to the help page if
      * the advanced help page has been queried on the command line (`show_advanced_options == true`).
      */
     void store_help_page_element(std::function<void()> printer, option_spec const spec)
     {
-        if (!(spec & option_spec::HIDDEN) && (!(spec & option_spec::ADVANCED) || show_advanced_options))
+        if (!(spec & option_spec::hidden) && (!(spec & option_spec::advanced) || show_advanced_options))
             parser_set_up_calls.push_back(std::move(printer));
     }
 };
