@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -134,7 +134,7 @@ private:
         if (line_is_paragraph)
             maybe_close_paragraph();
         else
-            std::cout << "<br />\n";
+            std::cout << "<br>\n";
     }
 
     /*!\brief Prints a help page list_item in HTML format to std::cout.
@@ -163,41 +163,7 @@ private:
     //!\brief Prints a help page footer in HTML format to std::cout.
     void print_footer()
     {
-        maybe_close_list();
-
-        // Print version, date and url.
-        std::cout << "<h2>Version</h2>\n"
-                  << "<strong>Last update:</strong> " << to_html(meta.date) << "<br>\n<strong>"
-                  << meta.app_name << " version:</strong> " << meta.version << "<br>\n"
-                  << "<strong>SeqAn version:</strong> " << SEQAN3_VERSION_MAJOR << '.' <<  SEQAN3_VERSION_MINOR << '.'
-                  << SEQAN3_VERSION_PATCH << "<br>\n";
-
-        if (!meta.url.empty())
-        {
-            std::cout << "<h2>Url</h2>\n"
-                    << meta.url << "<br>\n";
-        }
-        std::cout << "<br>\n";
-
-        // Print legal stuff
-        if ((!meta.short_copyright.empty()) || (!meta.long_copyright.empty()) || (!meta.citation.empty()))
-        {
-            std::cout << "<h2>Legal</h2>\n<strong>";
-
-            if (!meta.short_copyright.empty())
-                std::cout << meta.app_name << " Copyright: </strong>"
-                       << meta.short_copyright << "<br>\n<strong>";
-
-            std::cout << "SeqAn Copyright:</strong> 2006-2019 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.<br>\n<strong>";
-
-            if (!meta.citation.empty())
-                std::cout << "In your academic works please cite:</strong> " << meta.citation << "<br>\n";
-            else
-                std::cout << "</strong>";
-
-            if (!meta.long_copyright.empty())
-                std::cout << "For full copyright and/or warranty information see <tt>--copyright</tt>.\n";
-        }
+        maybe_close_paragraph();
 
         // Print HTML boilerplate footer.
         std::cout << "</body></html>";
@@ -267,6 +233,15 @@ private:
         return result;
     }
 
+    /*!\brief Format string as in_bold.
+     * \param[in] str The input string to format in bold.
+     * \returns The string `str` wrapped in bold formatting.
+     */
+    std::string in_bold(std::string const & str)
+    {
+        return "<strong>" + str + "</strong>";
+    }
+
     //!\brief Current state is either inside a html \<dl\> tag (true) or not (false).
     bool is_dl{false};
     //!\brief Current state is either inside a html \<p\> tag (true) or not (false).
