@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,15 +12,15 @@
 
 #pragma once
 
+#include <seqan3/std/charconv>
+#include <seqan3/std/concepts>
 #include <sstream>
 #include <string>
 #include <vector>
 
 #include <seqan3/argument_parser/detail/format_base.hpp>
-#include <seqan3/core/char_operations/predicate.hpp>
-#include <seqan3/core/detail/type_inspection.hpp>
-#include <seqan3/std/concepts>
-#include <seqan3/std/charconv>
+#include <seqan3/utility/char_operations/predicate.hpp>
+#include <seqan3/utility/detail/type_name_as_string.hpp>
 
 namespace seqan3::detail
 {
@@ -66,7 +66,7 @@ public:
      * \param[in] argc_ The number of command line arguments.
      * \param[in] argv_ The command line arguments to parse.
      */
-    format_parse(int const argc_, std::vector<std::string> && argv_) :
+    format_parse(int const argc_, std::vector<std::string> argv_) :
         argc{argc_ - 1}, argv{std::move(argv_)}
     {}
     //!\}
@@ -159,57 +159,15 @@ public:
             return is_char<'\0'>(id);
     }
 
-private:
-    //!\brief Describes the result of parsing the user input string given the respective option value type.
-    enum class option_parse_result
-    {
-        success, //!< Parsing of user input was successful.
-        error, //!< There was some error while trying to parse the user input.
-        overflow_error //!< Parsing was successful but the arithmetic value would cause an overflow.
-    };
-
-    /*!\brief Appends a double dash to a long identifier and returns it.
-    * \param[in] long_id The name of the long identifier.
-    * \returns The input long name prepended with a double dash.
-    */
-    std::string prepend_dash(std::string const & long_id)
-    {
-        return ("--" + long_id);
-    }
-
-    /*!\brief Appends a double dash to a short identifier and returns it.
-    * \param[in] short_id The name of the short identifier.
-    * \returns The input short name prepended with a single dash.
-    */
-    std::string prepend_dash(char const short_id)
-    {
-        return ("-" + std::string(1, short_id));
-    }
-
-    /*!\brief Returns "-[short_id]/--[long_id]" if both are non-empty or just one of them if the other is empty.
-    * \param[in] short_id The name of the short identifier.
-    * \param[in] long_id  The name of the long identifier.
-    * \returns The short_id prepended with a single dash and the long_id prepended with a double dash, separated by '/'.
-    */
-    std::string combine_option_names(char const short_id, std::string const & long_id)
-    {
-        if (short_id == '\0')
-            return prepend_dash(long_id);
-        else if (long_id.empty())
-            return prepend_dash(short_id);
-        else // both are set (note: both cannot be empty, this is caught before)
-            return prepend_dash(short_id) + "/" + prepend_dash(long_id);
-    }
-
     /*!\brief Finds the position of a short/long identifier in format_parse::argv.
+     * \tparam iterator_type The type of iterator that defines the range to search in.
      * \tparam id_type The identifier type; must be either of type `char` if it denotes a short identifier or
      *                 std::string if it denotes a long identifier.
      * \param[in] begin_it The iterator where to start the search of the identifier.
-     *                     Note that the end iterator is kept as a member variable.
-     * \param[in] id       The identifier to search for (must not contain dashes).
-     * \returns An iterator pointing to the first occurrence of the identifier in
-     *          the list pointed to by begin_t. If the list does not contain the
-     *          identifier `id`, the member variable `end_of_options_it` is returned.
+     * \param[in] end_it The iterator one past the end of where to search the identifier.
+     * \param[in] id The identifier to search for (must not contain dashes).
+     * \returns An iterator pointing to the first occurrence of `id` in the list pointed to by `begin_it`
+     *          or `end_it` if it is not contained.
      *
      * \details
      *
@@ -222,13 +180,13 @@ private:
      * The `id` is found by comparing every argument in argv to `id` prepended with two dashes (`--`)
      * or a prefix of such followed by the equal sign `=`.
      */
-    template <typename id_type>
-    std::vector<std::string>::iterator find_option_id(std::vector<std::string>::iterator const begin_it, id_type const & id)
+    template <typename iterator_type, typename id_type>
+    static iterator_type find_option_id(iterator_type begin_it, iterator_type end_it, id_type const & id)
     {
         if (is_empty_id(id))
-            return end_of_options_it;
+            return end_it;
 
-        return (std::find_if(begin_it, end_of_options_it,
+        return (std::find_if(begin_it, end_it,
             [&] (std::string const & current_arg)
             {
                 std::string full_id = prepend_dash(id);
@@ -248,6 +206,48 @@ private:
             }));
     }
 
+private:
+    //!\brief Describes the result of parsing the user input string given the respective option value type.
+    enum class option_parse_result
+    {
+        success, //!< Parsing of user input was successful.
+        error, //!< There was some error while trying to parse the user input.
+        overflow_error //!< Parsing was successful but the arithmetic value would cause an overflow.
+    };
+
+    /*!\brief Appends a double dash to a long identifier and returns it.
+    * \param[in] long_id The name of the long identifier.
+    * \returns The input long name prepended with a double dash.
+    */
+    static std::string prepend_dash(std::string const & long_id)
+    {
+        return {"--" + long_id};
+    }
+
+    /*!\brief Appends a double dash to a short identifier and returns it.
+    * \param[in] short_id The name of the short identifier.
+    * \returns The input short name prepended with a single dash.
+    */
+    static std::string prepend_dash(char const short_id)
+    {
+        return {"-" + std::string{short_id}};
+    }
+
+    /*!\brief Returns "-[short_id]/--[long_id]" if both are non-empty or just one of them if the other is empty.
+    * \param[in] short_id The name of the short identifier.
+    * \param[in] long_id  The name of the long identifier.
+    * \returns The short_id prepended with a single dash and the long_id prepended with a double dash, separated by '/'.
+    */
+    std::string combine_option_names(char const short_id, std::string const & long_id)
+    {
+        if (short_id == '\0')
+            return prepend_dash(long_id);
+        else if (long_id.empty())
+            return prepend_dash(short_id);
+        else // both are set (note: both cannot be empty, this is caught before)
+            return prepend_dash(short_id) + "/" + prepend_dash(long_id);
+    }
+
     /*!\brief Returns true and removes the long identifier if it is in format_parse::argv.
      * \param[in] long_id The long identifier of the flag to check.
      */
@@ -313,18 +313,34 @@ private:
      * \tparam option_t Must model seqan3::named_enumeration.
      * \param[out] value Stores the parsed value.
      * \param[in] in The input argument to be parsed.
-     * \returns seqan3::option_parse_result::error if `in` could not be found in the
-     *          seqan3::enumeration_names<option_t> map and otherwise seqan3::option_parse_result::success.
+     * \throws seqan3::user_input_error if `in` is not a key in seqan3::enumeration_names<option_t>.
+     * \returns seqan3::option_parse_result::success.
      */
     template <named_enumeration option_t>
-    option_parse_result parse_option_value(option_t & value, std::string_view const in)
+    option_parse_result parse_option_value(option_t & value, std::string const & in)
     {
         auto map = seqan3::enumeration_names<option_t>;
 
         if (auto it = map.find(in); it == map.end())
-            return option_parse_result::error;
+        {
+            std::vector<std::pair<std::string_view, option_t>> key_value_pairs(map.begin(), map.end());
+            std::ranges::sort(key_value_pairs, [] (auto pair1, auto pair2)
+                {
+                    if constexpr (std::totally_ordered<option_t>)
+                    {
+                        if (pair1.second != pair2.second)
+                            return pair1.second < pair2.second;
+                    }
+                    return pair1.first < pair2.first;
+                });
+
+            throw user_input_error{detail::to_string("You have chosen an invalid input value: ", in,
+                                                     ". Please use one of: ", key_value_pairs | std::views::keys)};
+        }
         else
+        {
             value = it->second;
+        }
 
         return option_parse_result::success;
     }
@@ -339,7 +355,7 @@ private:
 
     /*!\brief Parses the given option value and appends it to the target container.
      * \tparam container_option_t Must model the seqan3::sequence_container and
-     *                            its value_type must model the seqan3::input_stream_over
+     *                            its value_type must be parseable via parse_option_value
      *
      * \param[out] value The container that stores the parsed value.
      * \param[in] in The input argument to be parsed.
@@ -347,7 +363,10 @@ private:
      */
     template <sequence_container container_option_t>
     //!\cond
-        requires input_stream_over<std::istringstream, typename container_option_t::value_type>
+        requires requires (format_parse fp, typename container_option_t::value_type & container_value, std::string const & in)
+        {
+            SEQAN3_RETURN_TYPE_CONSTRAINT(fp.parse_option_value(container_value, in), std::same_as, option_parse_result);
+        }
     //!\endcond
     option_parse_result parse_option_value(container_option_t & value, std::string const & in)
     {
@@ -528,12 +547,12 @@ private:
     template <typename option_type, typename id_type>
     bool get_option_by_id(option_type & value, id_type const & id)
     {
-        auto it = find_option_id(argv.begin(), id);
+        auto it = find_option_id(argv.begin(), end_of_options_it, id);
 
         if (it != end_of_options_it)
             identify_and_retrieve_option_value(value, it, id);
 
-        if (find_option_id(it, id) != end_of_options_it) // should not be found again
+        if (find_option_id(it, end_of_options_it, id) != end_of_options_it) // should not be found again
            throw option_declared_multiple_times("Option " + prepend_dash(id) +
                                                 " is no list/container but declared multiple times.");
 
@@ -557,13 +576,16 @@ private:
     //!\endcond
     bool get_option_by_id(option_type & value, id_type const & id)
     {
-        auto it = find_option_id(argv.begin(), id);
+        auto it = find_option_id(argv.begin(), end_of_options_it, id);
         bool seen_at_least_once{it != end_of_options_it};
 
+        if (seen_at_least_once)
+            value.clear();
+
         while (it != end_of_options_it)
         {
             identify_and_retrieve_option_value(value, it, id);
-            it = find_option_id(it, id);
+            it = find_option_id(it, end_of_options_it, id);
         }
 
         return seen_at_least_once;
@@ -679,7 +701,7 @@ private:
         else // option is not set
         {
             // check if option is required
-            if (spec & option_spec::REQUIRED)
+            if (spec & option_spec::required)
                 throw required_option_missing("Option " + combine_option_names(short_id, long_id) +
                                               " is required but not set.");
         }
@@ -733,10 +755,12 @@ private:
                                     std::to_string(positional_option_calls.size()) +
                                     "). See -h/--help for more information.");
 
-        if (sequence_container<option_type> && !std::is_same_v<option_type, std::string>) // vector/list will be filled with all remaining arguments
+        if constexpr (sequence_container<option_type> && !std::is_same_v<option_type, std::string>) // vector/list will be filled with all remaining arguments
         {
             assert(positional_option_count == positional_option_calls.size()); // checked on set up.
 
+            value.clear();
+
             while (it != argv.end())
             {
                 auto res = parse_option_value(value, *it);
