@@ -1,8 +1,8 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
-// shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE
+// shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 /*!\file
@@ -18,8 +18,10 @@
 #include <fstream>
 #include <future>
 #include <iostream>
+#include <optional>
 #include <regex>
 
+#include <seqan3/argument_parser/auxiliary.hpp>
 #include <seqan3/argument_parser/detail/terminal.hpp>
 #include <seqan3/io/detail/misc.hpp>
 #include <seqan3/io/detail/safe_filesystem_entry.hpp>
@@ -268,12 +270,13 @@ public:
     }
 
     /*!\brief The central decision whether to perform the version check or not.
-     * \param[in] developer_approval Whether the developer approved (true) or not (false).
+     * \param[in] developer_approval Whether the developer approved (update_notifications::on) or not
+     *                               (update_notifications::off).
      * \param[in] user_approval      Whether the user approved (true) or not (false) or did not decide (unset optional).
      *
      * The following rules apply:
      *
-     * If the developer says no, it rules out all following decisions (even if the user specified --version-check 1).
+     * If the developer says no, it rules out all following decisions (even if the user specified --version-check true).
      * No cookie is ever written.
      *
      * If the environment variable SEQAN3_NO_VERSION_CHECK is set no version check is done (rules out all following).
@@ -291,9 +294,9 @@ public:
      * if possible (seqan3::detail::is_terminal()), what he wants to do, set the according cookie for the next time
      * and continue. If we cannot ask the user, the default kicks in (do the check).
      */
-    bool decide_if_check_is_performed(bool developer_approval, std::optional<bool> user_approval)
+    bool decide_if_check_is_performed(update_notifications developer_approval, std::optional<bool> user_approval)
     {
-        if (!developer_approval)
+        if (developer_approval == update_notifications::off)
             return false;
 
         if (std::getenv("SEQAN3_NO_VERSION_CHECK") != nullptr) // environment variable was set
