@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,14 +13,5 @@
 #pragma once
 
 #include <seqan3/core/concept/cereal.hpp>
-#include <seqan3/core/concept/core_language.hpp>
-#include <seqan3/core/concept/tuple.hpp>
-
-/*!\defgroup concept Concept
- * \ingroup core
- * \brief Additional concepts that are not specific to a SeqAn module.
- *
- * \details
- *
- * \todo write me.
- */
+#include <seqan3/utility/detail/exposition_only_concept.hpp>
+#include <seqan3/utility/tuple/concept.hpp>
