@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,12 +12,10 @@
 
 #pragma once
 
+#include <limits>
 #include <tuple>
 
-#include <meta/meta.hpp>
-
-#include <seqan3/core/type_list/type_list.hpp>
-#include <seqan3/core/type_traits/template_inspection.hpp>
+#include <seqan3/core/detail/template_inspection.hpp>
 
 namespace seqan3
 {
@@ -39,7 +37,7 @@ namespace seqan3
  * | seq            |      ✅      |      ✅       |       ✅      |
  * | id             |      ✅      |      ✅       |       ✅      |
  * | qual           |      ✅      |      ✅       |       ✅      |
- * | seq_qual       |      ✅      |      ✅       |       ✅      |
+ * | seq_qual       |      ✅      |              |              |
  * | offset         |             |      ✅       |       ✅      |
  * | bpp            |             |              |       ✅      |
  * | structure      |             |              |       ✅      |
@@ -66,9 +64,12 @@ enum class field
     // Fields used in multiple contexts ........................................
     seq,            //!< The "sequence", usually a range of nucleotides or amino acids.
     id,             //!< The identifier, usually a string.
-    qual,           //!< The qualities, usually in phred-score notation.
-    seq_qual,       //!< Sequence and qualities combined in one range.
-    offset,         //!< Sequence (SEQ) relative start position (0-based), unsigned value.
+    qual,           //!< The qualities, usually in Phred score notation.
+#ifdef SEQAN3_DEPRECATED_310
+    _seq_qual_deprecated, //!< [DEPRECATED] Sequence and qualities combined in one range. Use field::seq and field::qual instead.
+#endif // SEQAN3_DEPRECATED_310
+
+    offset,         //!< Sequence (seqan3::field::seq) relative start position (0-based), unsigned value.
 
     // Fields unique to structure io ...........................................
     bpp,            //!< Base pair probability matrix of interactions, usually a matrix of float numbers.
@@ -76,19 +77,19 @@ enum class field
     structured_seq, //!< Sequence and fixed interactions combined in one range.
     energy,         //!< Energy of a folded sequence, represented by one float number.
     react,          //!< Reactivity values of the sequence characters given in a vector of float numbers.
-    react_err,      //!< Reactivity error values given in a vector corresponding to REACT.
+    react_err,      //!< Reactivity error values given in a vector corresponding to seqan3::field::react.
     comment,        //!< Comment field of arbitrary content, usually a string.
 
     // Fields unique to alignment io ...........................................
-    alignment,      //!< The (pairwise) alignment stored in an seqan3::alignment object.
-    ref_id,         //!< The identifier of the (reference) sequence that SEQ was aligned to.
+    alignment,      //!< The (pairwise) alignment stored in an object that models seqan3::detail::pairwise_alignment.
+    ref_id,         //!< The identifier of the (reference) sequence that seqan3::field::seq was aligned to.
     ref_seq,        //!< The (reference) "sequence" information, usually a range of nucleotides or amino acids.
-    ref_offset,     //!< Sequence (REF_SEQ) relative start position (0-based), unsigned value.
-    header_ptr,     //!< A pointer to the seqan3::alignment_file_header object storing header information.
+    ref_offset,     //!< Sequence (seqan3::field::ref_seq) relative start position (0-based), unsigned value.
+    header_ptr,     //!< A pointer to the seqan3::sam_file_header object storing header information.
 
     flag,           //!< The alignment flag (bit information), `uint16_t` value.
     mate,           //!< The mate pair information given as a std::tuple of reference name, offset and template length.
-    mapq,           //!< The mapping quality of the SEQ alignment, usually a ohred-scaled score.
+    mapq,           //!< The mapping quality of the seqan3::field::seq alignment, usually a Phred-scaled score.
     cigar,          //!< The cigar vector (std::vector<seqan3::cigar>) representing the alignment in SAM/BAM format.
     tags,           //!< The optional tags in the SAM format, stored in a dictionary.
 
@@ -107,11 +108,15 @@ enum class field
     user_defined_8, //!< Identifier for user defined file formats and specialisations.
     user_defined_9, //!< Identifier for user defined file formats and specialisations.
 
+#ifdef SEQAN3_DEPRECATED_310
+    // deprecated lowercase:
+    seq_qual SEQAN3_DEPRECATED_310 = _seq_qual_deprecated, //!< [DEPRECATED] Sequence and qualities combined in one range. Use field::seq and field::qual instead.
+
     // deprecated uppercase:
     SEQ SEQAN3_DEPRECATED_310 = seq, //!< Please use the field name in lower case.
     ID SEQAN3_DEPRECATED_310 = id, //!< Please use the field name in lower case.
     QUAL SEQAN3_DEPRECATED_310 = qual, //!< Please use the field name in lower case.
-    SEQ_QUAL SEQAN3_DEPRECATED_310 = seq_qual, //!< Please use the field name in lower case.
+    SEQ_QUAL SEQAN3_DEPRECATED_310 = _seq_qual_deprecated, //!< [DEPRECATED] Sequence and qualities combined in one range. Use field::seq and field::qual instead.
     OFFSET SEQAN3_DEPRECATED_310 = offset, //!< Please use the field name in lower case.
     BPP SEQAN3_DEPRECATED_310 = bpp, //!< Please use the field name in lower case.
     STRUCTURE SEQAN3_DEPRECATED_310 = structure, //!< Please use the field name in lower case.
@@ -142,6 +147,7 @@ enum class field
     USER_DEFINED_7 SEQAN3_DEPRECATED_310 = user_defined_7, //!< Please use the field name in lower case.
     USER_DEFINED_8 SEQAN3_DEPRECATED_310 = user_defined_8, //!< Please use the field name in lower case.
     USER_DEFINED_9 SEQAN3_DEPRECATED_310 = user_defined_9, //!< Please use the field name in lower case.
+#endif // SEQAN3_DEPRECATED_310
 };
 
 // ----------------------------------------------------------------------------
@@ -171,6 +177,9 @@ struct fields
     //!\brief Special value that indicates that index_of() failed.
     static constexpr size_t npos = std::numeric_limits<size_t>::max();
 
+    //!\brief The size of fields.
+    static constexpr size_t size = sizeof...(fs);
+
     //!\brief Retrieve the position of field in the parameter pack.
     static constexpr size_t index_of(field f)
     {
@@ -271,6 +280,36 @@ public:
     {
         std::apply(expander, *this);
     }
+
+protected:
+    //!\privatesection
+
+    //!\brief A type alias for std::integral_constant
+    template <field f>
+    using field_constant = std::integral_constant<field, f>;
+
+    //!\brief This is basically the seqan3::get<f>(static_cast<tuple>(record)) implementation
+    template <field f, typename tuple_t>
+    static decltype(auto) get_impl(field_constant<f>, tuple_t && record_as_tuple)
+    {
+        static_assert(field_ids::contains(f), "The record does not contain the field you wish to retrieve.");
+#if SEQAN3_WORKAROUND_GCC_94967
+        // is_rvalue_reference_v can't be used, because tuple_t won't contain `&&` in the type due to reference
+        // collapsing
+        if constexpr (!std::is_lvalue_reference_v<tuple_t> && std::is_const_v<tuple_t>)
+        {
+            // A simple std::move(...) does not work, because it would mess up tuple_element types like `int const &`
+            using return_t = std::tuple_element_t<field_ids::index_of(f), tuple_t>;
+            return static_cast<return_t const &&>(std::get<field_ids::index_of(f)>(std::move(record_as_tuple)));
+        }
+        else
+        {
+            return std::get<field_ids::index_of(f)>(std::forward<tuple_t>(record_as_tuple));
+        }
+#else // ^^^ workaround / no workaround vvv
+        return std::get<field_ids::index_of(f)>(std::forward<tuple_t>(record_as_tuple));
+#endif // SEQAN3_WORKAROUND_GCC_94967
+    }
 };
 
 } // namespace seqan3
@@ -285,10 +324,8 @@ namespace std
  */
 template <typename field_types, typename field_ids>
 struct tuple_size<seqan3::record<field_types, field_ids>>
-{
-    //!\brief The value member. Delegates to same value on base_type.
-    static constexpr size_t value = tuple_size_v<typename seqan3::record<field_types, field_ids>::base_type>;
-};
+    : tuple_size<typename seqan3::record<field_types, field_ids>::base_type>
+{};
 
 /*!\brief Obtains the type of the specified element.
  * \implements seqan3::transformation_trait
@@ -297,25 +334,24 @@ struct tuple_size<seqan3::record<field_types, field_ids>>
  */
 template <size_t elem_no, typename field_types, typename field_ids>
 struct tuple_element<elem_no, seqan3::record<field_types, field_ids>>
-{
-    //!\brief The member type. Delegates to same type on base_type.
-    using type = std::tuple_element_t<elem_no, typename seqan3::record<field_types, field_ids>::base_type>;
-};
+    : tuple_element<elem_no, typename seqan3::record<field_types, field_ids>::base_type>
+{};
 
 } // namespace std
 
+#ifdef SEQAN3_DEPRECATED_310
 namespace seqan3
 {
 
 /*!\name Free function get() interface for seqan3::record based on seqan3::field.
- * \brief This is the tuple interface via seqan3::field, e.g. `get<field::seq>(tuple)`.
+ * \brief This is the tuple interface via seqan3::field, e.g. `seqan3::get<seqan3::field::seq>(record)`.
  * \relates seqan3::record
  * \{
  */
 
 //!\brief Free function get() for seqan3::record based on seqan3::field.
 template <field f, typename field_types, typename field_ids>
-auto & get(record<field_types, field_ids> & r)
+SEQAN3_DEPRECATED_310 auto & get(record<field_types, field_ids> & r)
 {
     static_assert(field_ids::contains(f), "The record does not contain the field you wish to retrieve.");
     return std::get<field_ids::index_of(f)>(r);
@@ -323,7 +359,7 @@ auto & get(record<field_types, field_ids> & r)
 
 //!\overload
 template <field f, typename field_types, typename field_ids>
-auto const & get(record<field_types, field_ids> const & r)
+SEQAN3_DEPRECATED_310 auto const & get(record<field_types, field_ids> const & r)
 {
     static_assert(field_ids::contains(f), "The record does not contain the field you wish to retrieve.");
     return std::get<field_ids::index_of(f)>(r);
@@ -331,7 +367,7 @@ auto const & get(record<field_types, field_ids> const & r)
 
 //!\overload
 template <field f, typename field_types, typename field_ids>
-auto && get(record<field_types, field_ids> && r)
+SEQAN3_DEPRECATED_310 auto && get(record<field_types, field_ids> && r)
 {
     static_assert(field_ids::contains(f), "The record does not contain the field you wish to retrieve.");
     return std::get<field_ids::index_of(f)>(std::move(r));
@@ -339,11 +375,18 @@ auto && get(record<field_types, field_ids> && r)
 
 //!\overload
 template <field f, typename field_types, typename field_ids>
-auto const && get(record<field_types, field_ids> const && r)
+SEQAN3_DEPRECATED_310 auto const && get(record<field_types, field_ids> const && r)
 {
     static_assert(field_ids::contains(f), "The record does not contain the field you wish to retrieve.");
+#if SEQAN3_WORKAROUND_GCC_94967
+    // A simple std::move(...) does not work, because it would mess up tuple_element types like `int const &`
+    using return_t = std::tuple_element_t<field_ids::index_of(f), record<field_types, field_ids>>;
+    return static_cast<return_t const &&>(std::get<field_ids::index_of(f)>(std::move(r)));
+#else // ^^^ workaround / no workaround vvv
     return std::get<field_ids::index_of(f)>(std::move(r));
+#endif // SEQAN3_WORKAROUND_GCC_94967
 }
 //!\}
 
 } // namespace seqan3
+#endif // SEQAN3_DEPRECATED_310
