@@ -1,11 +1,12 @@
-#include <seqan3/alphabet/nucleotide/dna4.hpp>
-#include <seqan3/range/views/complement.hpp>
-#include <seqan3/range/views/to.hpp>
 #include <seqan3/std/ranges>
 
+#include <seqan3/alphabet/nucleotide/dna4.hpp>
+#include <seqan3/alphabet/views/complement.hpp>
+#include <seqan3/utility/views/to.hpp>
+
 int main()
 {
-    using seqan3::operator""_dna4;
+    using namespace seqan3::literals;
 
     seqan3::dna4_vector vec{"ACGGTC"_dna4};
     auto vec_view2 = seqan3::views::complement(vec);
