@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -10,12 +10,12 @@
 
 #include <gtest/gtest.h>
 
+#include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
-#include <seqan3/alphabet/quality/phred42.hpp>
-#include <seqan3/core/concept/tuple.hpp>
-#include <seqan3/io/detail/record.hpp>
 #include <seqan3/io/record.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
+#include <seqan3/test/expect_same_type.hpp>
+#include <seqan3/utility/tuple/concept.hpp>
 
 using seqan3::operator""_dna4;
 
@@ -44,7 +44,9 @@ TEST(fields, usage)
     EXPECT_TRUE(default_fields::contains(seqan3::field::seq));
     EXPECT_TRUE(default_fields::contains(seqan3::field::id));
     EXPECT_TRUE(default_fields::contains(seqan3::field::qual));
-    EXPECT_FALSE(default_fields::contains(seqan3::field::seq_qual));
+#ifdef SEQAN3_DEPRECATED_310
+    EXPECT_FALSE(default_fields::contains(seqan3::field::_seq_qual_deprecated));
+#endif // SEQAN3_DEPRECATED_310
     EXPECT_EQ(default_fields::index_of(seqan3::field::seq), 0ul);
     EXPECT_EQ(default_fields::index_of(seqan3::field::id),  1ul);
     EXPECT_EQ(default_fields::index_of(seqan3::field::qual), 2ul);
@@ -96,25 +98,27 @@ TEST_F(record, get_by_type)
     EXPECT_RANGE_EQ(std::get<seqan3::dna4_vector>(r), "ACGT"_dna4);
 }
 
+#ifdef SEQAN3_DEPRECATED_310
 TEST_F(record, get_by_field)
 {
     record_type r{"MY ID", "ACGT"_dna4};
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
     EXPECT_EQ(seqan3::get<seqan3::field::id>(r), "MY ID");
     EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(r), "ACGT"_dna4);
+#pragma GCC diagnostic pop
 }
 
-// ----------------------------------------------------------------------------
-// detail/record.hpp
-// ----------------------------------------------------------------------------
-
-TEST(detail, select_types_with_ids)
+TEST_F(record, gcc_issue_94967)
 {
-    using types         = seqan3::type_list<std::string, seqan3::dna4_vector, std::vector<seqan3::phred42>>;
-    using types_as_ids  = seqan3::fields<seqan3::field::id, seqan3::field::seq, seqan3::field::qual>;
-    using selected_ids  = seqan3::fields<seqan3::field::qual, seqan3::field::id>;
+    record_type r{"MY ID", "ACGT"_dna4};
 
-    using selected_types = typename seqan3::detail::select_types_with_ids<types, types_as_ids, selected_ids>::type;
-
-    EXPECT_TRUE((std::is_same_v<selected_types, seqan3::type_list<std::vector<seqan3::phred42>, std::string>>));
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    // gcc 7 implemented a different std::get(const &&) definition which was later changed by
+    // https://wg21.link/lwg2485
+    EXPECT_SAME_TYPE(std::string const &&, decltype(seqan3::get<seqan3::field::id>(std::move(std::as_const(r)))));
+#pragma GCC diagnostic pop
 }
+#endif // SEQAN3_DEPRECATED_310
