@@ -1,26 +1,24 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <iterator>
-#include <fstream>
-#include <sstream>
-
 #include <gtest/gtest.h>
 
-#include <range/v3/view/map.hpp>
-
-#include <seqan3/alphabet/nucleotide/rna4.hpp>
-#include <seqan3/io/structure_file/input.hpp>
-#include <seqan3/range/views/convert.hpp>
 #include <seqan3/std/algorithm>
+#include <fstream>
 #include <seqan3/std/iterator>
 #include <seqan3/std/ranges>
+#include <sstream>
+
+#include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
+#include <seqan3/alphabet/nucleotide/rna4.hpp>
+#include <seqan3/io/structure_file/input.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
 #include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/utility/views/convert.hpp>
 
 using seqan3::operator""_rna5;
 using seqan3::operator""_wuss51;
@@ -268,9 +266,20 @@ struct structure_file_input_read : public ::testing::Test
         counter = 0ul;
         for (auto & rec : fin)
         {
+
+#ifdef SEQAN3_DEPRECATED_310
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
             EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
             EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
             EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
+#pragma GCC diagnostic pop
+#endif // SEQAN3_DEPRECATED_310
+
+            EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
+            EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
+            EXPECT_RANGE_EQ(rec.sequence_structure(), structure_comp[counter]);
+
             ++counter;
         }
 
@@ -304,9 +313,20 @@ TEST_F(structure_file_input_read, record_general)
     size_t counter = 0ul;
     for (auto & rec : fin)
     {
+
+#ifdef SEQAN3_DEPRECATED_310
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
+#pragma GCC diagnostic pop
+#endif // SEQAN3_DEPRECATED_310
+
+        EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
+        EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
+        EXPECT_RANGE_EQ(rec.sequence_structure(), structure_comp[counter]);
+
         ++counter;
     }
     EXPECT_EQ(counter, num_records);
@@ -364,25 +384,32 @@ TEST_F(structure_file_input_read, record_file_view)
                                                     seqan3::field::structure,
                                                     seqan3::field::energy>{}};
 
-#if !SEQAN3_WORKAROUND_GCC_93983
     auto minimum_length_filter = std::views::filter([] (auto const & rec)
     {
-        return size(seqan3::get<seqan3::field::seq>(rec)) >= 5;
+        return size(rec.sequence()) >= 5;
     });
-#endif
 
     size_t counter = 0ul; // the first record will be filtered out
-#if SEQAN3_WORKAROUND_GCC_93983
-    for (auto & rec : fin /*| minimum_length_filter*/)
-#else // ^^^ workaround / no workaround vvv
     for (auto & rec : fin | minimum_length_filter)
-#endif // SEQAN3_WORKAROUND_GCC_93983
     {
+
+#ifdef SEQAN3_DEPRECATED_310
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec),  id_comp[counter]);
         bpp_test(seqan3::get<seqan3::field::bpp>(rec), interaction_comp[counter]);
         EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
         EXPECT_DOUBLE_EQ(seqan3::get<seqan3::field::energy>(rec).value(), energy_comp[counter]);
+#pragma GCC diagnostic pop
+#endif // SEQAN3_DEPRECATED_310
+
+        EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
+        EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
+        bpp_test(rec.base_pair_probability_matrix(), interaction_comp[counter]);
+        EXPECT_RANGE_EQ(rec.sequence_structure(), structure_comp[counter]);
+        EXPECT_DOUBLE_EQ(rec.energy().value(), energy_comp[counter]);
+
         ++counter;
     }
     EXPECT_EQ(counter, num_records);
